PCB Environment: Layer Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
Layer Class Reference

## Public Member Functions
void | setNumber (uint N)
void | setType (SignalType t)
uint | getNumber () const
SignalType | getType () const
bool | hasType (SignalType t) const
bool | isSignal () const
bool | isPower () const
bool | isGround () const
std::string | str () const
PyObject * | getPy () const

## Static Public Member Functions
static bool | rangesOverlap (uint z0, uint z1, uint Z0, uint Z1)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Layer.hpp